####
nark
####

``nark`` is a Hamster API library with advanced filtering and sorting.

This PyPI package is a temporary placeholder until all
assets are uploaded and put in their right place.

(Coming soon!)

